Class: OsunyApi::CommunicationBlockAgenda
- Inherits:
-
Object
- Object
- OsunyApi::CommunicationBlockAgenda
- Defined in:
- lib/osuny_api/models/communication_block_agenda.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#data ⇒ Object
Returns the value of attribute data.
-
#html_class ⇒ Object
For advanced use.
-
#id ⇒ Object
Returns the value of attribute id.
-
#migration_identifier ⇒ Object
Returns the value of attribute migration_identifier.
-
#position ⇒ Object
Returns the value of attribute position.
-
#published ⇒ Object
Returns the value of attribute published.
-
#template_kind ⇒ Object
Template kind of the blocks.
-
#title ⇒ Object
Returns the value of attribute title.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CommunicationBlockAgenda
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ CommunicationBlockAgenda
Initializes the object
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/osuny_api/models/communication_block_agenda.rb', line 97 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `OsunyApi::CommunicationBlockAgenda` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `OsunyApi::CommunicationBlockAgenda`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'migration_identifier') self.migration_identifier = attributes[:'migration_identifier'] end if attributes.key?(:'template_kind') self.template_kind = attributes[:'template_kind'] end if attributes.key?(:'title') self.title = attributes[:'title'] end if attributes.key?(:'position') self.position = attributes[:'position'] end if attributes.key?(:'published') self.published = attributes[:'published'] else self.published = true end if attributes.key?(:'html_class') self.html_class = attributes[:'html_class'] end if attributes.key?(:'data') self.data = attributes[:'data'] end end |
Instance Attribute Details
#data ⇒ Object
Returns the value of attribute data.
32 33 34 |
# File 'lib/osuny_api/models/communication_block_agenda.rb', line 32 def data @data end |
#html_class ⇒ Object
For advanced use. Add an HTML class for custom purposes.
30 31 32 |
# File 'lib/osuny_api/models/communication_block_agenda.rb', line 30 def html_class @html_class end |
#id ⇒ Object
Returns the value of attribute id.
16 17 18 |
# File 'lib/osuny_api/models/communication_block_agenda.rb', line 16 def id @id end |
#migration_identifier ⇒ Object
Returns the value of attribute migration_identifier.
18 19 20 |
# File 'lib/osuny_api/models/communication_block_agenda.rb', line 18 def migration_identifier @migration_identifier end |
#position ⇒ Object
Returns the value of attribute position.
25 26 27 |
# File 'lib/osuny_api/models/communication_block_agenda.rb', line 25 def position @position end |
#published ⇒ Object
Returns the value of attribute published.
27 28 29 |
# File 'lib/osuny_api/models/communication_block_agenda.rb', line 27 def published @published end |
#template_kind ⇒ Object
Template kind of the blocks.
21 22 23 |
# File 'lib/osuny_api/models/communication_block_agenda.rb', line 21 def template_kind @template_kind end |
#title ⇒ Object
Returns the value of attribute title.
23 24 25 |
# File 'lib/osuny_api/models/communication_block_agenda.rb', line 23 def title @title end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/osuny_api/models/communication_block_agenda.rb', line 57 def self.attribute_map { :'id' => :'id', :'migration_identifier' => :'migration_identifier', :'template_kind' => :'template_kind', :'title' => :'title', :'position' => :'position', :'published' => :'published', :'html_class' => :'html_class', :'data' => :'data' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
200 201 202 |
# File 'lib/osuny_api/models/communication_block_agenda.rb', line 200 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
85 86 87 88 89 90 91 92 93 |
# File 'lib/osuny_api/models/communication_block_agenda.rb', line 85 def self.openapi_nullable Set.new([ :'id', :'migration_identifier', :'title', :'position', :'html_class', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/osuny_api/models/communication_block_agenda.rb', line 71 def self.openapi_types { :'id' => :'Object', :'migration_identifier' => :'Object', :'template_kind' => :'Object', :'title' => :'Object', :'position' => :'Object', :'published' => :'Object', :'html_class' => :'Object', :'data' => :'Object' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
172 173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/osuny_api/models/communication_block_agenda.rb', line 172 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && migration_identifier == o.migration_identifier && template_kind == o.template_kind && title == o.title && position == o.position && published == o.published && html_class == o.html_class && data == o.data end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 |
# File 'lib/osuny_api/models/communication_block_agenda.rb', line 230 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model OsunyApi.const_get(type).build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
299 300 301 302 303 304 305 306 307 308 309 310 311 |
# File 'lib/osuny_api/models/communication_block_agenda.rb', line 299 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 |
# File 'lib/osuny_api/models/communication_block_agenda.rb', line 207 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) elsif attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) end end self end |
#eql?(o) ⇒ Boolean
187 188 189 |
# File 'lib/osuny_api/models/communication_block_agenda.rb', line 187 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
193 194 195 |
# File 'lib/osuny_api/models/communication_block_agenda.rb', line 193 def hash [id, migration_identifier, template_kind, title, position, published, html_class, data].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
147 148 149 150 |
# File 'lib/osuny_api/models/communication_block_agenda.rb', line 147 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
275 276 277 |
# File 'lib/osuny_api/models/communication_block_agenda.rb', line 275 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
281 282 283 284 285 286 287 288 289 290 291 292 293 |
# File 'lib/osuny_api/models/communication_block_agenda.rb', line 281 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
269 270 271 |
# File 'lib/osuny_api/models/communication_block_agenda.rb', line 269 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
154 155 156 157 158 |
# File 'lib/osuny_api/models/communication_block_agenda.rb', line 154 def valid? template_kind_validator = EnumAttributeValidator.new('Object', ['agenda']) return false unless template_kind_validator.valid?(@template_kind) true end |