Class: OsunyApi::CommunicationBlockAgendaData

Inherits:
Object
  • Object
show all
Defined in:
lib/osuny_api/models/communication_block_agenda_data.rb

Overview

Data of the block. The structure depends on the template kind.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CommunicationBlockAgendaData

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/osuny_api/models/communication_block_agenda_data.rb', line 127

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `OsunyApi::CommunicationBlockAgendaData` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `OsunyApi::CommunicationBlockAgendaData`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'layout')
    self.layout = attributes[:'layout']
  end

  if attributes.key?(:'mode')
    self.mode = attributes[:'mode']
  end

  if attributes.key?(:'category_id')
    self.category_id = attributes[:'category_id']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'quantity')
    self.quantity = attributes[:'quantity']
  end

  if attributes.key?(:'time')
    self.time = attributes[:'time']
  end

  if attributes.key?(:'no_event_message')
    self.no_event_message = attributes[:'no_event_message']
  end

  if attributes.key?(:'option_categories')
    self.option_categories = attributes[:'option_categories']
  end

  if attributes.key?(:'option_dates')
    self.option_dates = attributes[:'option_dates']
  end

  if attributes.key?(:'option_image')
    self.option_image = attributes[:'option_image']
  end

  if attributes.key?(:'option_subtitle')
    self.option_subtitle = attributes[:'option_subtitle']
  end

  if attributes.key?(:'option_summary')
    self.option_summary = attributes[:'option_summary']
  end

  if attributes.key?(:'option_status')
    self.option_status = attributes[:'option_status']
  end

  if attributes.key?(:'kind_parent')
    self.kind_parent = attributes[:'kind_parent']
  end

  if attributes.key?(:'kind_child')
    self.kind_child = attributes[:'kind_child']
  end

  if attributes.key?(:'kind_recurring')
    self.kind_recurring = attributes[:'kind_recurring']
  end

  if attributes.key?(:'elements')
    if (value = attributes[:'elements']).is_a?(Array)
      self.elements = value
    end
  end
end

Instance Attribute Details

#category_idObject

Returns the value of attribute category_id.



21
22
23
# File 'lib/osuny_api/models/communication_block_agenda_data.rb', line 21

def category_id
  @category_id
end

#descriptionObject

Returns the value of attribute description.



23
24
25
# File 'lib/osuny_api/models/communication_block_agenda_data.rb', line 23

def description
  @description
end

#elementsObject

Returns the value of attribute elements.



49
50
51
# File 'lib/osuny_api/models/communication_block_agenda_data.rb', line 49

def elements
  @elements
end

#kind_childObject

Returns the value of attribute kind_child.



45
46
47
# File 'lib/osuny_api/models/communication_block_agenda_data.rb', line 45

def kind_child
  @kind_child
end

#kind_parentObject

Returns the value of attribute kind_parent.



43
44
45
# File 'lib/osuny_api/models/communication_block_agenda_data.rb', line 43

def kind_parent
  @kind_parent
end

#kind_recurringObject

Returns the value of attribute kind_recurring.



47
48
49
# File 'lib/osuny_api/models/communication_block_agenda_data.rb', line 47

def kind_recurring
  @kind_recurring
end

#layoutObject

Returns the value of attribute layout.



17
18
19
# File 'lib/osuny_api/models/communication_block_agenda_data.rb', line 17

def layout
  @layout
end

#modeObject

Returns the value of attribute mode.



19
20
21
# File 'lib/osuny_api/models/communication_block_agenda_data.rb', line 19

def mode
  @mode
end

#no_event_messageObject

Returns the value of attribute no_event_message.



29
30
31
# File 'lib/osuny_api/models/communication_block_agenda_data.rb', line 29

def no_event_message
  @no_event_message
end

#option_categoriesObject

Returns the value of attribute option_categories.



31
32
33
# File 'lib/osuny_api/models/communication_block_agenda_data.rb', line 31

def option_categories
  @option_categories
end

#option_datesObject

Returns the value of attribute option_dates.



33
34
35
# File 'lib/osuny_api/models/communication_block_agenda_data.rb', line 33

def option_dates
  @option_dates
end

#option_imageObject

Returns the value of attribute option_image.



35
36
37
# File 'lib/osuny_api/models/communication_block_agenda_data.rb', line 35

def option_image
  @option_image
end

#option_statusObject

Returns the value of attribute option_status.



41
42
43
# File 'lib/osuny_api/models/communication_block_agenda_data.rb', line 41

def option_status
  @option_status
end

#option_subtitleObject

Returns the value of attribute option_subtitle.



37
38
39
# File 'lib/osuny_api/models/communication_block_agenda_data.rb', line 37

def option_subtitle
  @option_subtitle
end

#option_summaryObject

Returns the value of attribute option_summary.



39
40
41
# File 'lib/osuny_api/models/communication_block_agenda_data.rb', line 39

def option_summary
  @option_summary
end

#quantityObject

Returns the value of attribute quantity.



25
26
27
# File 'lib/osuny_api/models/communication_block_agenda_data.rb', line 25

def quantity
  @quantity
end

#timeObject

Returns the value of attribute time.



27
28
29
# File 'lib/osuny_api/models/communication_block_agenda_data.rb', line 27

def time
  @time
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/osuny_api/models/communication_block_agenda_data.rb', line 74

def self.attribute_map
  {
    :'layout' => :'layout',
    :'mode' => :'mode',
    :'category_id' => :'category_id',
    :'description' => :'description',
    :'quantity' => :'quantity',
    :'time' => :'time',
    :'no_event_message' => :'no_event_message',
    :'option_categories' => :'option_categories',
    :'option_dates' => :'option_dates',
    :'option_image' => :'option_image',
    :'option_subtitle' => :'option_subtitle',
    :'option_summary' => :'option_summary',
    :'option_status' => :'option_status',
    :'kind_parent' => :'kind_parent',
    :'kind_child' => :'kind_child',
    :'kind_recurring' => :'kind_recurring',
    :'elements' => :'elements'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



299
300
301
# File 'lib/osuny_api/models/communication_block_agenda_data.rb', line 299

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



120
121
122
123
# File 'lib/osuny_api/models/communication_block_agenda_data.rb', line 120

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/osuny_api/models/communication_block_agenda_data.rb', line 97

def self.openapi_types
  {
    :'layout' => :'Object',
    :'mode' => :'Object',
    :'category_id' => :'Object',
    :'description' => :'Object',
    :'quantity' => :'Object',
    :'time' => :'Object',
    :'no_event_message' => :'Object',
    :'option_categories' => :'Object',
    :'option_dates' => :'Object',
    :'option_image' => :'Object',
    :'option_subtitle' => :'Object',
    :'option_summary' => :'Object',
    :'option_status' => :'Object',
    :'kind_parent' => :'Object',
    :'kind_child' => :'Object',
    :'kind_recurring' => :'Object',
    :'elements' => :'Object'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
# File 'lib/osuny_api/models/communication_block_agenda_data.rb', line 262

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      layout == o.layout &&
      mode == o.mode &&
      category_id == o.category_id &&
      description == o.description &&
      quantity == o.quantity &&
      time == o.time &&
      no_event_message == o.no_event_message &&
      option_categories == o.option_categories &&
      option_dates == o.option_dates &&
      option_image == o.option_image &&
      option_subtitle == o.option_subtitle &&
      option_summary == o.option_summary &&
      option_status == o.option_status &&
      kind_parent == o.kind_parent &&
      kind_child == o.kind_child &&
      kind_recurring == o.kind_recurring &&
      elements == o.elements
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
# File 'lib/osuny_api/models/communication_block_agenda_data.rb', line 329

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    OsunyApi.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



398
399
400
401
402
403
404
405
406
407
408
409
410
# File 'lib/osuny_api/models/communication_block_agenda_data.rb', line 398

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
# File 'lib/osuny_api/models/communication_block_agenda_data.rb', line 306

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    elsif attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


286
287
288
# File 'lib/osuny_api/models/communication_block_agenda_data.rb', line 286

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



292
293
294
# File 'lib/osuny_api/models/communication_block_agenda_data.rb', line 292

def hash
  [layout, mode, category_id, description, quantity, time, no_event_message, option_categories, option_dates, option_image, option_subtitle, option_summary, option_status, kind_parent, kind_child, kind_recurring, elements].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



213
214
215
216
# File 'lib/osuny_api/models/communication_block_agenda_data.rb', line 213

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



374
375
376
# File 'lib/osuny_api/models/communication_block_agenda_data.rb', line 374

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



380
381
382
383
384
385
386
387
388
389
390
391
392
# File 'lib/osuny_api/models/communication_block_agenda_data.rb', line 380

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



368
369
370
# File 'lib/osuny_api/models/communication_block_agenda_data.rb', line 368

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



220
221
222
223
224
225
226
227
228
# File 'lib/osuny_api/models/communication_block_agenda_data.rb', line 220

def valid?
  layout_validator = EnumAttributeValidator.new('Object', ['grid', 'list', 'large'])
  return false unless layout_validator.valid?(@layout)
  mode_validator = EnumAttributeValidator.new('Object', ['all', 'category', 'selection'])
  return false unless mode_validator.valid?(@mode)
  time_validator = EnumAttributeValidator.new('Object', ['current', 'future_or_current', 'future', 'archive'])
  return false unless time_validator.valid?(@time)
  true
end