Class: OsunyApi::CommunicationBlockContactData

Inherits:
Object
  • Object
show all
Defined in:
lib/osuny_api/models/communication_block_contact_data.rb

Overview

Data of the block. The structure depends on the template kind.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CommunicationBlockContactData

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/osuny_api/models/communication_block_contact_data.rb', line 121

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `OsunyApi::CommunicationBlockContactData` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `OsunyApi::CommunicationBlockContactData`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'address')
    self.address = attributes[:'address']
  end

  if attributes.key?(:'information')
    self.information = attributes[:'information']
  end

  if attributes.key?(:'zipcode')
    self.zipcode = attributes[:'zipcode']
  end

  if attributes.key?(:'city')
    self.city = attributes[:'city']
  end

  if attributes.key?(:'country')
    self.country = attributes[:'country']
  end

  if attributes.key?(:'url')
    self.url = attributes[:'url']
  end

  if attributes.key?(:'phone_numbers')
    if (value = attributes[:'phone_numbers']).is_a?(Array)
      self.phone_numbers = value
    end
  end

  if attributes.key?(:'emails')
    if (value = attributes[:'emails']).is_a?(Array)
      self.emails = value
    end
  end

  if attributes.key?(:'social_mastodon')
    self.social_mastodon = attributes[:'social_mastodon']
  end

  if attributes.key?(:'social_x')
    self.social_x = attributes[:'social_x']
  end

  if attributes.key?(:'social_linkedin')
    self.social_linkedin = attributes[:'social_linkedin']
  end

  if attributes.key?(:'social_youtube')
    self.social_youtube = attributes[:'social_youtube']
  end

  if attributes.key?(:'social_vimeo')
    self.social_vimeo = attributes[:'social_vimeo']
  end

  if attributes.key?(:'social_peertube')
    self.social_peertube = attributes[:'social_peertube']
  end

  if attributes.key?(:'social_instagram')
    self.social_instagram = attributes[:'social_instagram']
  end

  if attributes.key?(:'social_facebook')
    self.social_facebook = attributes[:'social_facebook']
  end

  if attributes.key?(:'social_tiktok')
    self.social_tiktok = attributes[:'social_tiktok']
  end

  if attributes.key?(:'social_github')
    self.social_github = attributes[:'social_github']
  end

  if attributes.key?(:'elements')
    if (value = attributes[:'elements']).is_a?(Array)
      self.elements = value
    end
  end
end

Instance Attribute Details

#addressObject

Returns the value of attribute address.



21
22
23
# File 'lib/osuny_api/models/communication_block_contact_data.rb', line 21

def address
  @address
end

#cityObject

Returns the value of attribute city.



27
28
29
# File 'lib/osuny_api/models/communication_block_contact_data.rb', line 27

def city
  @city
end

#countryObject

Returns the value of attribute country.



29
30
31
# File 'lib/osuny_api/models/communication_block_contact_data.rb', line 29

def country
  @country
end

#descriptionObject

Returns the value of attribute description.



17
18
19
# File 'lib/osuny_api/models/communication_block_contact_data.rb', line 17

def description
  @description
end

#elementsObject

Returns the value of attribute elements.



57
58
59
# File 'lib/osuny_api/models/communication_block_contact_data.rb', line 57

def elements
  @elements
end

#emailsObject

Returns the value of attribute emails.



35
36
37
# File 'lib/osuny_api/models/communication_block_contact_data.rb', line 35

def emails
  @emails
end

#informationObject

Returns the value of attribute information.



23
24
25
# File 'lib/osuny_api/models/communication_block_contact_data.rb', line 23

def information
  @information
end

#nameObject

Returns the value of attribute name.



19
20
21
# File 'lib/osuny_api/models/communication_block_contact_data.rb', line 19

def name
  @name
end

#phone_numbersObject

Returns the value of attribute phone_numbers.



33
34
35
# File 'lib/osuny_api/models/communication_block_contact_data.rb', line 33

def phone_numbers
  @phone_numbers
end

#social_facebookObject

Returns the value of attribute social_facebook.



51
52
53
# File 'lib/osuny_api/models/communication_block_contact_data.rb', line 51

def social_facebook
  @social_facebook
end

#social_githubObject

Returns the value of attribute social_github.



55
56
57
# File 'lib/osuny_api/models/communication_block_contact_data.rb', line 55

def social_github
  @social_github
end

#social_instagramObject

Returns the value of attribute social_instagram.



49
50
51
# File 'lib/osuny_api/models/communication_block_contact_data.rb', line 49

def social_instagram
  @social_instagram
end

#social_linkedinObject

Returns the value of attribute social_linkedin.



41
42
43
# File 'lib/osuny_api/models/communication_block_contact_data.rb', line 41

def social_linkedin
  @social_linkedin
end

#social_mastodonObject

Returns the value of attribute social_mastodon.



37
38
39
# File 'lib/osuny_api/models/communication_block_contact_data.rb', line 37

def social_mastodon
  @social_mastodon
end

#social_peertubeObject

Returns the value of attribute social_peertube.



47
48
49
# File 'lib/osuny_api/models/communication_block_contact_data.rb', line 47

def social_peertube
  @social_peertube
end

#social_tiktokObject

Returns the value of attribute social_tiktok.



53
54
55
# File 'lib/osuny_api/models/communication_block_contact_data.rb', line 53

def social_tiktok
  @social_tiktok
end

#social_vimeoObject

Returns the value of attribute social_vimeo.



45
46
47
# File 'lib/osuny_api/models/communication_block_contact_data.rb', line 45

def social_vimeo
  @social_vimeo
end

#social_xObject

Returns the value of attribute social_x.



39
40
41
# File 'lib/osuny_api/models/communication_block_contact_data.rb', line 39

def social_x
  @social_x
end

#social_youtubeObject

Returns the value of attribute social_youtube.



43
44
45
# File 'lib/osuny_api/models/communication_block_contact_data.rb', line 43

def social_youtube
  @social_youtube
end

#urlObject

Returns the value of attribute url.



31
32
33
# File 'lib/osuny_api/models/communication_block_contact_data.rb', line 31

def url
  @url
end

#zipcodeObject

Returns the value of attribute zipcode.



25
26
27
# File 'lib/osuny_api/models/communication_block_contact_data.rb', line 25

def zipcode
  @zipcode
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/osuny_api/models/communication_block_contact_data.rb', line 60

def self.attribute_map
  {
    :'description' => :'description',
    :'name' => :'name',
    :'address' => :'address',
    :'information' => :'information',
    :'zipcode' => :'zipcode',
    :'city' => :'city',
    :'country' => :'country',
    :'url' => :'url',
    :'phone_numbers' => :'phone_numbers',
    :'emails' => :'emails',
    :'social_mastodon' => :'social_mastodon',
    :'social_x' => :'social_x',
    :'social_linkedin' => :'social_linkedin',
    :'social_youtube' => :'social_youtube',
    :'social_vimeo' => :'social_vimeo',
    :'social_peertube' => :'social_peertube',
    :'social_instagram' => :'social_instagram',
    :'social_facebook' => :'social_facebook',
    :'social_tiktok' => :'social_tiktok',
    :'social_github' => :'social_github',
    :'elements' => :'elements'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



281
282
283
# File 'lib/osuny_api/models/communication_block_contact_data.rb', line 281

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



114
115
116
117
# File 'lib/osuny_api/models/communication_block_contact_data.rb', line 114

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/osuny_api/models/communication_block_contact_data.rb', line 87

def self.openapi_types
  {
    :'description' => :'Object',
    :'name' => :'Object',
    :'address' => :'Object',
    :'information' => :'Object',
    :'zipcode' => :'Object',
    :'city' => :'Object',
    :'country' => :'Object',
    :'url' => :'Object',
    :'phone_numbers' => :'Object',
    :'emails' => :'Object',
    :'social_mastodon' => :'Object',
    :'social_x' => :'Object',
    :'social_linkedin' => :'Object',
    :'social_youtube' => :'Object',
    :'social_vimeo' => :'Object',
    :'social_peertube' => :'Object',
    :'social_instagram' => :'Object',
    :'social_facebook' => :'Object',
    :'social_tiktok' => :'Object',
    :'social_github' => :'Object',
    :'elements' => :'Object'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
# File 'lib/osuny_api/models/communication_block_contact_data.rb', line 240

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      description == o.description &&
      name == o.name &&
      address == o.address &&
      information == o.information &&
      zipcode == o.zipcode &&
      city == o.city &&
      country == o.country &&
      url == o.url &&
      phone_numbers == o.phone_numbers &&
      emails == o.emails &&
      social_mastodon == o.social_mastodon &&
      social_x == o.social_x &&
      social_linkedin == o.social_linkedin &&
      social_youtube == o.social_youtube &&
      social_vimeo == o.social_vimeo &&
      social_peertube == o.social_peertube &&
      social_instagram == o.social_instagram &&
      social_facebook == o.social_facebook &&
      social_tiktok == o.social_tiktok &&
      social_github == o.social_github &&
      elements == o.elements
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
# File 'lib/osuny_api/models/communication_block_contact_data.rb', line 311

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    OsunyApi.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



380
381
382
383
384
385
386
387
388
389
390
391
392
# File 'lib/osuny_api/models/communication_block_contact_data.rb', line 380

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
# File 'lib/osuny_api/models/communication_block_contact_data.rb', line 288

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    elsif attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


268
269
270
# File 'lib/osuny_api/models/communication_block_contact_data.rb', line 268

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



274
275
276
# File 'lib/osuny_api/models/communication_block_contact_data.rb', line 274

def hash
  [description, name, address, information, zipcode, city, country, url, phone_numbers, emails, social_mastodon, social_x, social_linkedin, social_youtube, social_vimeo, social_peertube, social_instagram, social_facebook, social_tiktok, social_github, elements].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



227
228
229
230
# File 'lib/osuny_api/models/communication_block_contact_data.rb', line 227

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



356
357
358
# File 'lib/osuny_api/models/communication_block_contact_data.rb', line 356

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



362
363
364
365
366
367
368
369
370
371
372
373
374
# File 'lib/osuny_api/models/communication_block_contact_data.rb', line 362

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



350
351
352
# File 'lib/osuny_api/models/communication_block_contact_data.rb', line 350

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



234
235
236
# File 'lib/osuny_api/models/communication_block_contact_data.rb', line 234

def valid?
  true
end