Class: OsunyApi::CommunicationBlockExhibitionsData
- Inherits:
-
Object
- Object
- OsunyApi::CommunicationBlockExhibitionsData
- Defined in:
- lib/osuny_api/models/communication_block_exhibitions_data.rb
Overview
Data of the block. The structure depends on the template kind.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#category_id ⇒ Object
Returns the value of attribute category_id.
-
#description ⇒ Object
Returns the value of attribute description.
-
#elements ⇒ Object
Returns the value of attribute elements.
-
#layout ⇒ Object
Returns the value of attribute layout.
-
#mode ⇒ Object
Returns the value of attribute mode.
-
#no_exhibition_message ⇒ Object
Returns the value of attribute no_exhibition_message.
-
#option_categories ⇒ Object
Returns the value of attribute option_categories.
-
#option_dates ⇒ Object
Returns the value of attribute option_dates.
-
#option_image ⇒ Object
Returns the value of attribute option_image.
-
#option_status ⇒ Object
Returns the value of attribute option_status.
-
#option_subtitle ⇒ Object
Returns the value of attribute option_subtitle.
-
#option_summary ⇒ Object
Returns the value of attribute option_summary.
-
#quantity ⇒ Object
Returns the value of attribute quantity.
-
#time ⇒ Object
Returns the value of attribute time.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CommunicationBlockExhibitionsData
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ CommunicationBlockExhibitionsData
Initializes the object
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/osuny_api/models/communication_block_exhibitions_data.rb', line 115 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `OsunyApi::CommunicationBlockExhibitionsData` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `OsunyApi::CommunicationBlockExhibitionsData`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'layout') self.layout = attributes[:'layout'] end if attributes.key?(:'mode') self.mode = attributes[:'mode'] end if attributes.key?(:'category_id') self.category_id = attributes[:'category_id'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'quantity') self.quantity = attributes[:'quantity'] end if attributes.key?(:'time') self.time = attributes[:'time'] end if attributes.key?(:'no_exhibition_message') self. = attributes[:'no_exhibition_message'] end if attributes.key?(:'option_categories') self.option_categories = attributes[:'option_categories'] end if attributes.key?(:'option_dates') self.option_dates = attributes[:'option_dates'] end if attributes.key?(:'option_image') self.option_image = attributes[:'option_image'] end if attributes.key?(:'option_subtitle') self.option_subtitle = attributes[:'option_subtitle'] end if attributes.key?(:'option_summary') self.option_summary = attributes[:'option_summary'] end if attributes.key?(:'option_status') self.option_status = attributes[:'option_status'] end if attributes.key?(:'elements') if (value = attributes[:'elements']).is_a?(Array) self.elements = value end end end |
Instance Attribute Details
#category_id ⇒ Object
Returns the value of attribute category_id.
21 22 23 |
# File 'lib/osuny_api/models/communication_block_exhibitions_data.rb', line 21 def category_id @category_id end |
#description ⇒ Object
Returns the value of attribute description.
23 24 25 |
# File 'lib/osuny_api/models/communication_block_exhibitions_data.rb', line 23 def description @description end |
#elements ⇒ Object
Returns the value of attribute elements.
43 44 45 |
# File 'lib/osuny_api/models/communication_block_exhibitions_data.rb', line 43 def elements @elements end |
#layout ⇒ Object
Returns the value of attribute layout.
17 18 19 |
# File 'lib/osuny_api/models/communication_block_exhibitions_data.rb', line 17 def layout @layout end |
#mode ⇒ Object
Returns the value of attribute mode.
19 20 21 |
# File 'lib/osuny_api/models/communication_block_exhibitions_data.rb', line 19 def mode @mode end |
#no_exhibition_message ⇒ Object
Returns the value of attribute no_exhibition_message.
29 30 31 |
# File 'lib/osuny_api/models/communication_block_exhibitions_data.rb', line 29 def @no_exhibition_message end |
#option_categories ⇒ Object
Returns the value of attribute option_categories.
31 32 33 |
# File 'lib/osuny_api/models/communication_block_exhibitions_data.rb', line 31 def option_categories @option_categories end |
#option_dates ⇒ Object
Returns the value of attribute option_dates.
33 34 35 |
# File 'lib/osuny_api/models/communication_block_exhibitions_data.rb', line 33 def option_dates @option_dates end |
#option_image ⇒ Object
Returns the value of attribute option_image.
35 36 37 |
# File 'lib/osuny_api/models/communication_block_exhibitions_data.rb', line 35 def option_image @option_image end |
#option_status ⇒ Object
Returns the value of attribute option_status.
41 42 43 |
# File 'lib/osuny_api/models/communication_block_exhibitions_data.rb', line 41 def option_status @option_status end |
#option_subtitle ⇒ Object
Returns the value of attribute option_subtitle.
37 38 39 |
# File 'lib/osuny_api/models/communication_block_exhibitions_data.rb', line 37 def option_subtitle @option_subtitle end |
#option_summary ⇒ Object
Returns the value of attribute option_summary.
39 40 41 |
# File 'lib/osuny_api/models/communication_block_exhibitions_data.rb', line 39 def option_summary @option_summary end |
#quantity ⇒ Object
Returns the value of attribute quantity.
25 26 27 |
# File 'lib/osuny_api/models/communication_block_exhibitions_data.rb', line 25 def quantity @quantity end |
#time ⇒ Object
Returns the value of attribute time.
27 28 29 |
# File 'lib/osuny_api/models/communication_block_exhibitions_data.rb', line 27 def time @time end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/osuny_api/models/communication_block_exhibitions_data.rb', line 68 def self.attribute_map { :'layout' => :'layout', :'mode' => :'mode', :'category_id' => :'category_id', :'description' => :'description', :'quantity' => :'quantity', :'time' => :'time', :'no_exhibition_message' => :'no_exhibition_message', :'option_categories' => :'option_categories', :'option_dates' => :'option_dates', :'option_image' => :'option_image', :'option_subtitle' => :'option_subtitle', :'option_summary' => :'option_summary', :'option_status' => :'option_status', :'elements' => :'elements' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
272 273 274 |
# File 'lib/osuny_api/models/communication_block_exhibitions_data.rb', line 272 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
108 109 110 111 |
# File 'lib/osuny_api/models/communication_block_exhibitions_data.rb', line 108 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/osuny_api/models/communication_block_exhibitions_data.rb', line 88 def self.openapi_types { :'layout' => :'Object', :'mode' => :'Object', :'category_id' => :'Object', :'description' => :'Object', :'quantity' => :'Object', :'time' => :'Object', :'no_exhibition_message' => :'Object', :'option_categories' => :'Object', :'option_dates' => :'Object', :'option_image' => :'Object', :'option_subtitle' => :'Object', :'option_summary' => :'Object', :'option_status' => :'Object', :'elements' => :'Object' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'lib/osuny_api/models/communication_block_exhibitions_data.rb', line 238 def ==(o) return true if self.equal?(o) self.class == o.class && layout == o.layout && mode == o.mode && category_id == o.category_id && description == o.description && quantity == o.quantity && time == o.time && == o. && option_categories == o.option_categories && option_dates == o.option_dates && option_image == o.option_image && option_subtitle == o.option_subtitle && option_summary == o.option_summary && option_status == o.option_status && elements == o.elements end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 |
# File 'lib/osuny_api/models/communication_block_exhibitions_data.rb', line 302 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model OsunyApi.const_get(type).build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
371 372 373 374 375 376 377 378 379 380 381 382 383 |
# File 'lib/osuny_api/models/communication_block_exhibitions_data.rb', line 371 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 |
# File 'lib/osuny_api/models/communication_block_exhibitions_data.rb', line 279 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) elsif attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) end end self end |
#eql?(o) ⇒ Boolean
259 260 261 |
# File 'lib/osuny_api/models/communication_block_exhibitions_data.rb', line 259 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
265 266 267 |
# File 'lib/osuny_api/models/communication_block_exhibitions_data.rb', line 265 def hash [layout, mode, category_id, description, quantity, time, , option_categories, option_dates, option_image, option_subtitle, option_summary, option_status, elements].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
189 190 191 192 |
# File 'lib/osuny_api/models/communication_block_exhibitions_data.rb', line 189 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
347 348 349 |
# File 'lib/osuny_api/models/communication_block_exhibitions_data.rb', line 347 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
353 354 355 356 357 358 359 360 361 362 363 364 365 |
# File 'lib/osuny_api/models/communication_block_exhibitions_data.rb', line 353 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
341 342 343 |
# File 'lib/osuny_api/models/communication_block_exhibitions_data.rb', line 341 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
196 197 198 199 200 201 202 203 204 |
# File 'lib/osuny_api/models/communication_block_exhibitions_data.rb', line 196 def valid? layout_validator = EnumAttributeValidator.new('Object', ['grid', 'list', 'large']) return false unless layout_validator.valid?(@layout) mode_validator = EnumAttributeValidator.new('Object', ['all', 'category', 'selection']) return false unless mode_validator.valid?(@mode) time_validator = EnumAttributeValidator.new('Object', ['current', 'future_or_current', 'future', 'archive']) return false unless time_validator.valid?(@time) true end |