Class: OsunyApi::CommunicationBlockOrganizationsData

Inherits:
Object
  • Object
show all
Defined in:
lib/osuny_api/models/communication_block_organizations_data.rb

Overview

Data of the block. The structure depends on the template kind.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CommunicationBlockOrganizationsData

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/osuny_api/models/communication_block_organizations_data.rb', line 103

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `OsunyApi::CommunicationBlockOrganizationsData` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `OsunyApi::CommunicationBlockOrganizationsData`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'layout')
    self.layout = attributes[:'layout']
  end

  if attributes.key?(:'mode')
    self.mode = attributes[:'mode']
  end

  if attributes.key?(:'category_id')
    self.category_id = attributes[:'category_id']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'alphabetical')
    self.alphabetical = attributes[:'alphabetical']
  end

  if attributes.key?(:'option_link')
    self.option_link = attributes[:'option_link']
  end

  if attributes.key?(:'option_logo')
    self. = attributes[:'option_logo']
  end

  if attributes.key?(:'option_summary')
    self.option_summary = attributes[:'option_summary']
  end

  if attributes.key?(:'option_address')
    self.option_address = attributes[:'option_address']
  end

  if attributes.key?(:'option_filters')
    self.option_filters = attributes[:'option_filters']
  end

  if attributes.key?(:'elements')
    if (value = attributes[:'elements']).is_a?(Array)
      self.elements = value
    end
  end
end

Instance Attribute Details

#alphabeticalObject

Returns the value of attribute alphabetical.



25
26
27
# File 'lib/osuny_api/models/communication_block_organizations_data.rb', line 25

def alphabetical
  @alphabetical
end

#category_idObject

Returns the value of attribute category_id.



21
22
23
# File 'lib/osuny_api/models/communication_block_organizations_data.rb', line 21

def category_id
  @category_id
end

#descriptionObject

Returns the value of attribute description.



23
24
25
# File 'lib/osuny_api/models/communication_block_organizations_data.rb', line 23

def description
  @description
end

#elementsObject

Returns the value of attribute elements.



37
38
39
# File 'lib/osuny_api/models/communication_block_organizations_data.rb', line 37

def elements
  @elements
end

#layoutObject

Returns the value of attribute layout.



17
18
19
# File 'lib/osuny_api/models/communication_block_organizations_data.rb', line 17

def layout
  @layout
end

#modeObject

Returns the value of attribute mode.



19
20
21
# File 'lib/osuny_api/models/communication_block_organizations_data.rb', line 19

def mode
  @mode
end

#option_addressObject

Returns the value of attribute option_address.



33
34
35
# File 'lib/osuny_api/models/communication_block_organizations_data.rb', line 33

def option_address
  @option_address
end

#option_filtersObject

Returns the value of attribute option_filters.



35
36
37
# File 'lib/osuny_api/models/communication_block_organizations_data.rb', line 35

def option_filters
  @option_filters
end

Returns the value of attribute option_link.



27
28
29
# File 'lib/osuny_api/models/communication_block_organizations_data.rb', line 27

def option_link
  @option_link
end

#option_logoObject

Returns the value of attribute option_logo.



29
30
31
# File 'lib/osuny_api/models/communication_block_organizations_data.rb', line 29

def 
  @option_logo
end

#option_summaryObject

Returns the value of attribute option_summary.



31
32
33
# File 'lib/osuny_api/models/communication_block_organizations_data.rb', line 31

def option_summary
  @option_summary
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/osuny_api/models/communication_block_organizations_data.rb', line 62

def self.attribute_map
  {
    :'layout' => :'layout',
    :'mode' => :'mode',
    :'category_id' => :'category_id',
    :'description' => :'description',
    :'alphabetical' => :'alphabetical',
    :'option_link' => :'option_link',
    :'option_logo' => :'option_logo',
    :'option_summary' => :'option_summary',
    :'option_address' => :'option_address',
    :'option_filters' => :'option_filters',
    :'elements' => :'elements'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



233
234
235
# File 'lib/osuny_api/models/communication_block_organizations_data.rb', line 233

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



96
97
98
99
# File 'lib/osuny_api/models/communication_block_organizations_data.rb', line 96

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/osuny_api/models/communication_block_organizations_data.rb', line 79

def self.openapi_types
  {
    :'layout' => :'Object',
    :'mode' => :'Object',
    :'category_id' => :'Object',
    :'description' => :'Object',
    :'alphabetical' => :'Object',
    :'option_link' => :'Object',
    :'option_logo' => :'Object',
    :'option_summary' => :'Object',
    :'option_address' => :'Object',
    :'option_filters' => :'Object',
    :'elements' => :'Object'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
# File 'lib/osuny_api/models/communication_block_organizations_data.rb', line 202

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      layout == o.layout &&
      mode == o.mode &&
      category_id == o.category_id &&
      description == o.description &&
      alphabetical == o.alphabetical &&
      option_link == o.option_link &&
       == o. &&
      option_summary == o.option_summary &&
      option_address == o.option_address &&
      option_filters == o.option_filters &&
      elements == o.elements
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
# File 'lib/osuny_api/models/communication_block_organizations_data.rb', line 263

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    OsunyApi.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



332
333
334
335
336
337
338
339
340
341
342
343
344
# File 'lib/osuny_api/models/communication_block_organizations_data.rb', line 332

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
# File 'lib/osuny_api/models/communication_block_organizations_data.rb', line 240

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    elsif attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


220
221
222
# File 'lib/osuny_api/models/communication_block_organizations_data.rb', line 220

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



226
227
228
# File 'lib/osuny_api/models/communication_block_organizations_data.rb', line 226

def hash
  [layout, mode, category_id, description, alphabetical, option_link, , option_summary, option_address, option_filters, elements].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



165
166
167
168
# File 'lib/osuny_api/models/communication_block_organizations_data.rb', line 165

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



308
309
310
# File 'lib/osuny_api/models/communication_block_organizations_data.rb', line 308

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



314
315
316
317
318
319
320
321
322
323
324
325
326
# File 'lib/osuny_api/models/communication_block_organizations_data.rb', line 314

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



302
303
304
# File 'lib/osuny_api/models/communication_block_organizations_data.rb', line 302

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



172
173
174
175
176
177
178
# File 'lib/osuny_api/models/communication_block_organizations_data.rb', line 172

def valid?
  layout_validator = EnumAttributeValidator.new('Object', ['grid', 'large', 'map', 'carousel'])
  return false unless layout_validator.valid?(@layout)
  mode_validator = EnumAttributeValidator.new('Object', ['selection', 'category'])
  return false unless mode_validator.valid?(@mode)
  true
end