Class: OsunyApi::CommunicationWebsite
- Inherits:
-
Object
- Object
- OsunyApi::CommunicationWebsite
- Defined in:
- lib/osuny_api/models/communication_website.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#deuxfleurs ⇒ Object
Returns the value of attribute deuxfleurs.
-
#features ⇒ Object
Returns the value of attribute features.
-
#git ⇒ Object
Returns the value of attribute git.
-
#hosting ⇒ Object
Returns the value of attribute hosting.
-
#id ⇒ Object
Returns the value of attribute id.
-
#localizations ⇒ Object
Localizations of the website.
-
#showcase ⇒ Object
Returns the value of attribute showcase.
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
-
#url ⇒ Object
Returns the value of attribute url.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CommunicationWebsite
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ CommunicationWebsite
Initializes the object
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/osuny_api/models/communication_website.rb', line 101 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `OsunyApi::CommunicationWebsite` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `OsunyApi::CommunicationWebsite`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'url') self.url = attributes[:'url'] end if attributes.key?(:'hosting') self.hosting = attributes[:'hosting'] end if attributes.key?(:'deuxfleurs') self.deuxfleurs = attributes[:'deuxfleurs'] end if attributes.key?(:'features') self.features = attributes[:'features'] end if attributes.key?(:'git') self.git = attributes[:'git'] end if attributes.key?(:'showcase') self.showcase = attributes[:'showcase'] end if attributes.key?(:'localizations') if (value = attributes[:'localizations']).is_a?(Hash) self.localizations = value end end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] end end |
Instance Attribute Details
#created_at ⇒ Object
Returns the value of attribute created_at.
33 34 35 |
# File 'lib/osuny_api/models/communication_website.rb', line 33 def created_at @created_at end |
#deuxfleurs ⇒ Object
Returns the value of attribute deuxfleurs.
22 23 24 |
# File 'lib/osuny_api/models/communication_website.rb', line 22 def deuxfleurs @deuxfleurs end |
#features ⇒ Object
Returns the value of attribute features.
24 25 26 |
# File 'lib/osuny_api/models/communication_website.rb', line 24 def features @features end |
#git ⇒ Object
Returns the value of attribute git.
26 27 28 |
# File 'lib/osuny_api/models/communication_website.rb', line 26 def git @git end |
#hosting ⇒ Object
Returns the value of attribute hosting.
20 21 22 |
# File 'lib/osuny_api/models/communication_website.rb', line 20 def hosting @hosting end |
#id ⇒ Object
Returns the value of attribute id.
16 17 18 |
# File 'lib/osuny_api/models/communication_website.rb', line 16 def id @id end |
#localizations ⇒ Object
Localizations of the website. The key is the languageās ISO 639-1 code.
31 32 33 |
# File 'lib/osuny_api/models/communication_website.rb', line 31 def localizations @localizations end |
#showcase ⇒ Object
Returns the value of attribute showcase.
28 29 30 |
# File 'lib/osuny_api/models/communication_website.rb', line 28 def showcase @showcase end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
35 36 37 |
# File 'lib/osuny_api/models/communication_website.rb', line 35 def updated_at @updated_at end |
#url ⇒ Object
Returns the value of attribute url.
18 19 20 |
# File 'lib/osuny_api/models/communication_website.rb', line 18 def url @url end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
60 61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/osuny_api/models/communication_website.rb', line 60 def self.attribute_map { :'id' => :'id', :'url' => :'url', :'hosting' => :'hosting', :'deuxfleurs' => :'deuxfleurs', :'features' => :'features', :'git' => :'git', :'showcase' => :'showcase', :'localizations' => :'localizations', :'created_at' => :'created_at', :'updated_at' => :'updated_at' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
214 215 216 |
# File 'lib/osuny_api/models/communication_website.rb', line 214 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
92 93 94 95 96 97 |
# File 'lib/osuny_api/models/communication_website.rb', line 92 def self.openapi_nullable Set.new([ :'url', :'hosting', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/osuny_api/models/communication_website.rb', line 76 def self.openapi_types { :'id' => :'Object', :'url' => :'Object', :'hosting' => :'Object', :'deuxfleurs' => :'Object', :'features' => :'Object', :'git' => :'Object', :'showcase' => :'Object', :'localizations' => :'Object', :'created_at' => :'Object', :'updated_at' => :'Object' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
184 185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/osuny_api/models/communication_website.rb', line 184 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && url == o.url && hosting == o.hosting && deuxfleurs == o.deuxfleurs && features == o.features && git == o.git && showcase == o.showcase && localizations == o.localizations && created_at == o.created_at && updated_at == o.updated_at end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 |
# File 'lib/osuny_api/models/communication_website.rb', line 244 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model OsunyApi.const_get(type).build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
313 314 315 316 317 318 319 320 321 322 323 324 325 |
# File 'lib/osuny_api/models/communication_website.rb', line 313 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/osuny_api/models/communication_website.rb', line 221 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) elsif attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) end end self end |
#eql?(o) ⇒ Boolean
201 202 203 |
# File 'lib/osuny_api/models/communication_website.rb', line 201 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
207 208 209 |
# File 'lib/osuny_api/models/communication_website.rb', line 207 def hash [id, url, hosting, deuxfleurs, features, git, showcase, localizations, created_at, updated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
159 160 161 162 |
# File 'lib/osuny_api/models/communication_website.rb', line 159 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
289 290 291 |
# File 'lib/osuny_api/models/communication_website.rb', line 289 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
295 296 297 298 299 300 301 302 303 304 305 306 307 |
# File 'lib/osuny_api/models/communication_website.rb', line 295 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
283 284 285 |
# File 'lib/osuny_api/models/communication_website.rb', line 283 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
166 167 168 169 170 |
# File 'lib/osuny_api/models/communication_website.rb', line 166 def valid? hosting_validator = EnumAttributeValidator.new('Object', ['undefined', 'deuxfleurs', 'apache', 'nginx', 'netlify']) return false unless hosting_validator.valid?(@hosting) true end |