Class: OsunyApi::CommunicationWebsiteAgendaCategoryLocalization
- Inherits:
-
Object
- Object
- OsunyApi::CommunicationWebsiteAgendaCategoryLocalization
- Defined in:
- lib/osuny_api/models/communication_website_agenda_category_localization.rb
Instance Attribute Summary collapse
-
#blocks ⇒ Object
Returns the value of attribute blocks.
-
#breadcrumb_title ⇒ Object
Returns the value of attribute breadcrumb_title.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#featured_image ⇒ Object
Returns the value of attribute featured_image.
-
#header_cta ⇒ Object
Returns the value of attribute header_cta.
-
#header_cta_label ⇒ Object
Returns the value of attribute header_cta_label.
-
#header_cta_url ⇒ Object
Returns the value of attribute header_cta_url.
-
#header_text ⇒ Object
Returns the value of attribute header_text.
-
#id ⇒ Object
Returns the value of attribute id.
-
#meta_description ⇒ Object
Returns the value of attribute meta_description.
-
#migration_identifier ⇒ Object
Returns the value of attribute migration_identifier.
-
#name ⇒ Object
Returns the value of attribute name.
-
#path ⇒ Object
Returns the value of attribute path.
-
#slug ⇒ Object
Returns the value of attribute slug.
-
#subtitle ⇒ Object
Returns the value of attribute subtitle.
-
#summary ⇒ Object
Returns the value of attribute summary.
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CommunicationWebsiteAgendaCategoryLocalization
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ CommunicationWebsiteAgendaCategoryLocalization
Initializes the object
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'lib/osuny_api/models/communication_website_agenda_category_localization.rb', line 114 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `OsunyApi::CommunicationWebsiteAgendaCategoryLocalization` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `OsunyApi::CommunicationWebsiteAgendaCategoryLocalization`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'migration_identifier') self.migration_identifier = attributes[:'migration_identifier'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'breadcrumb_title') self. = attributes[:'breadcrumb_title'] end if attributes.key?(:'featured_image') self.featured_image = attributes[:'featured_image'] end if attributes.key?(:'header_cta') self.header_cta = attributes[:'header_cta'] end if attributes.key?(:'header_cta_label') self.header_cta_label = attributes[:'header_cta_label'] end if attributes.key?(:'header_cta_url') self.header_cta_url = attributes[:'header_cta_url'] end if attributes.key?(:'header_text') self.header_text = attributes[:'header_text'] end if attributes.key?(:'meta_description') self. = attributes[:'meta_description'] end if attributes.key?(:'path') self.path = attributes[:'path'] end if attributes.key?(:'slug') self.slug = attributes[:'slug'] end if attributes.key?(:'subtitle') self.subtitle = attributes[:'subtitle'] end if attributes.key?(:'summary') self.summary = attributes[:'summary'] end if attributes.key?(:'blocks') if (value = attributes[:'blocks']).is_a?(Array) self.blocks = value end end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] end end |
Instance Attribute Details
#blocks ⇒ Object
Returns the value of attribute blocks.
44 45 46 |
# File 'lib/osuny_api/models/communication_website_agenda_category_localization.rb', line 44 def blocks @blocks end |
#breadcrumb_title ⇒ Object
Returns the value of attribute breadcrumb_title.
22 23 24 |
# File 'lib/osuny_api/models/communication_website_agenda_category_localization.rb', line 22 def @breadcrumb_title end |
#created_at ⇒ Object
Returns the value of attribute created_at.
46 47 48 |
# File 'lib/osuny_api/models/communication_website_agenda_category_localization.rb', line 46 def created_at @created_at end |
#featured_image ⇒ Object
Returns the value of attribute featured_image.
24 25 26 |
# File 'lib/osuny_api/models/communication_website_agenda_category_localization.rb', line 24 def featured_image @featured_image end |
#header_cta ⇒ Object
Returns the value of attribute header_cta.
26 27 28 |
# File 'lib/osuny_api/models/communication_website_agenda_category_localization.rb', line 26 def header_cta @header_cta end |
#header_cta_label ⇒ Object
Returns the value of attribute header_cta_label.
28 29 30 |
# File 'lib/osuny_api/models/communication_website_agenda_category_localization.rb', line 28 def header_cta_label @header_cta_label end |
#header_cta_url ⇒ Object
Returns the value of attribute header_cta_url.
30 31 32 |
# File 'lib/osuny_api/models/communication_website_agenda_category_localization.rb', line 30 def header_cta_url @header_cta_url end |
#header_text ⇒ Object
Returns the value of attribute header_text.
32 33 34 |
# File 'lib/osuny_api/models/communication_website_agenda_category_localization.rb', line 32 def header_text @header_text end |
#id ⇒ Object
Returns the value of attribute id.
16 17 18 |
# File 'lib/osuny_api/models/communication_website_agenda_category_localization.rb', line 16 def id @id end |
#meta_description ⇒ Object
Returns the value of attribute meta_description.
34 35 36 |
# File 'lib/osuny_api/models/communication_website_agenda_category_localization.rb', line 34 def @meta_description end |
#migration_identifier ⇒ Object
Returns the value of attribute migration_identifier.
18 19 20 |
# File 'lib/osuny_api/models/communication_website_agenda_category_localization.rb', line 18 def migration_identifier @migration_identifier end |
#name ⇒ Object
Returns the value of attribute name.
20 21 22 |
# File 'lib/osuny_api/models/communication_website_agenda_category_localization.rb', line 20 def name @name end |
#path ⇒ Object
Returns the value of attribute path.
36 37 38 |
# File 'lib/osuny_api/models/communication_website_agenda_category_localization.rb', line 36 def path @path end |
#slug ⇒ Object
Returns the value of attribute slug.
38 39 40 |
# File 'lib/osuny_api/models/communication_website_agenda_category_localization.rb', line 38 def slug @slug end |
#subtitle ⇒ Object
Returns the value of attribute subtitle.
40 41 42 |
# File 'lib/osuny_api/models/communication_website_agenda_category_localization.rb', line 40 def subtitle @subtitle end |
#summary ⇒ Object
Returns the value of attribute summary.
42 43 44 |
# File 'lib/osuny_api/models/communication_website_agenda_category_localization.rb', line 42 def summary @summary end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
48 49 50 |
# File 'lib/osuny_api/models/communication_website_agenda_category_localization.rb', line 48 def updated_at @updated_at end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/osuny_api/models/communication_website_agenda_category_localization.rb', line 51 def self.attribute_map { :'id' => :'id', :'migration_identifier' => :'migration_identifier', :'name' => :'name', :'breadcrumb_title' => :'breadcrumb_title', :'featured_image' => :'featured_image', :'header_cta' => :'header_cta', :'header_cta_label' => :'header_cta_label', :'header_cta_url' => :'header_cta_url', :'header_text' => :'header_text', :'meta_description' => :'meta_description', :'path' => :'path', :'slug' => :'slug', :'subtitle' => :'subtitle', :'summary' => :'summary', :'blocks' => :'blocks', :'created_at' => :'created_at', :'updated_at' => :'updated_at' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
250 251 252 |
# File 'lib/osuny_api/models/communication_website_agenda_category_localization.rb', line 250 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/osuny_api/models/communication_website_agenda_category_localization.rb', line 97 def self.openapi_nullable Set.new([ :'migration_identifier', :'breadcrumb_title', :'header_cta', :'header_cta_label', :'header_cta_url', :'header_text', :'meta_description', :'path', :'subtitle', :'summary', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/osuny_api/models/communication_website_agenda_category_localization.rb', line 74 def self.openapi_types { :'id' => :'Object', :'migration_identifier' => :'Object', :'name' => :'Object', :'breadcrumb_title' => :'Object', :'featured_image' => :'Object', :'header_cta' => :'Object', :'header_cta_label' => :'Object', :'header_cta_url' => :'Object', :'header_text' => :'Object', :'meta_description' => :'Object', :'path' => :'Object', :'slug' => :'Object', :'subtitle' => :'Object', :'summary' => :'Object', :'blocks' => :'Object', :'created_at' => :'Object', :'updated_at' => :'Object' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'lib/osuny_api/models/communication_website_agenda_category_localization.rb', line 213 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && migration_identifier == o.migration_identifier && name == o.name && == o. && featured_image == o.featured_image && header_cta == o.header_cta && header_cta_label == o.header_cta_label && header_cta_url == o.header_cta_url && header_text == o.header_text && == o. && path == o.path && slug == o.slug && subtitle == o.subtitle && summary == o.summary && blocks == o.blocks && created_at == o.created_at && updated_at == o.updated_at end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 |
# File 'lib/osuny_api/models/communication_website_agenda_category_localization.rb', line 280 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model OsunyApi.const_get(type).build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
349 350 351 352 353 354 355 356 357 358 359 360 361 |
# File 'lib/osuny_api/models/communication_website_agenda_category_localization.rb', line 349 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 |
# File 'lib/osuny_api/models/communication_website_agenda_category_localization.rb', line 257 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) elsif attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) end end self end |
#eql?(o) ⇒ Boolean
237 238 239 |
# File 'lib/osuny_api/models/communication_website_agenda_category_localization.rb', line 237 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
243 244 245 |
# File 'lib/osuny_api/models/communication_website_agenda_category_localization.rb', line 243 def hash [id, migration_identifier, name, , featured_image, header_cta, header_cta_label, header_cta_url, header_text, , path, slug, subtitle, summary, blocks, created_at, updated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
200 201 202 203 |
# File 'lib/osuny_api/models/communication_website_agenda_category_localization.rb', line 200 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
325 326 327 |
# File 'lib/osuny_api/models/communication_website_agenda_category_localization.rb', line 325 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
331 332 333 334 335 336 337 338 339 340 341 342 343 |
# File 'lib/osuny_api/models/communication_website_agenda_category_localization.rb', line 331 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
319 320 321 |
# File 'lib/osuny_api/models/communication_website_agenda_category_localization.rb', line 319 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
207 208 209 |
# File 'lib/osuny_api/models/communication_website_agenda_category_localization.rb', line 207 def valid? true end |