Class: OsunyApi::CommunicationWebsiteLocalization
- Inherits:
-
Object
- Object
- OsunyApi::CommunicationWebsiteLocalization
- Defined in:
- lib/osuny_api/models/communication_website_localization.rb
Instance Attribute Summary collapse
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#id ⇒ Object
Returns the value of attribute id.
-
#name ⇒ Object
Returns the value of attribute name.
-
#published ⇒ Object
Returns the value of attribute published.
-
#published_at ⇒ Object
Returns the value of attribute published_at.
-
#social_email ⇒ Object
Returns the value of attribute social_email.
-
#social_facebook ⇒ Object
Returns the value of attribute social_facebook.
-
#social_github ⇒ Object
Returns the value of attribute social_github.
-
#social_instagram ⇒ Object
Returns the value of attribute social_instagram.
-
#social_linkedin ⇒ Object
Returns the value of attribute social_linkedin.
-
#social_mastodon ⇒ Object
Returns the value of attribute social_mastodon.
-
#social_peertube ⇒ Object
Returns the value of attribute social_peertube.
-
#social_tiktok ⇒ Object
Returns the value of attribute social_tiktok.
-
#social_vimeo ⇒ Object
Returns the value of attribute social_vimeo.
-
#social_x ⇒ Object
Returns the value of attribute social_x.
-
#social_youtube ⇒ Object
Returns the value of attribute social_youtube.
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CommunicationWebsiteLocalization
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ CommunicationWebsiteLocalization
Initializes the object
116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'lib/osuny_api/models/communication_website_localization.rb', line 116 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `OsunyApi::CommunicationWebsiteLocalization` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `OsunyApi::CommunicationWebsiteLocalization`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'published') self.published = attributes[:'published'] end if attributes.key?(:'published_at') self.published_at = attributes[:'published_at'] end if attributes.key?(:'social_email') self. = attributes[:'social_email'] end if attributes.key?(:'social_facebook') self. = attributes[:'social_facebook'] end if attributes.key?(:'social_github') self. = attributes[:'social_github'] end if attributes.key?(:'social_instagram') self. = attributes[:'social_instagram'] end if attributes.key?(:'social_linkedin') self. = attributes[:'social_linkedin'] end if attributes.key?(:'social_mastodon') self. = attributes[:'social_mastodon'] end if attributes.key?(:'social_peertube') self. = attributes[:'social_peertube'] end if attributes.key?(:'social_tiktok') self. = attributes[:'social_tiktok'] end if attributes.key?(:'social_vimeo') self. = attributes[:'social_vimeo'] end if attributes.key?(:'social_x') self. = attributes[:'social_x'] end if attributes.key?(:'social_youtube') self. = attributes[:'social_youtube'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] end end |
Instance Attribute Details
#created_at ⇒ Object
Returns the value of attribute created_at.
46 47 48 |
# File 'lib/osuny_api/models/communication_website_localization.rb', line 46 def created_at @created_at end |
#id ⇒ Object
Returns the value of attribute id.
16 17 18 |
# File 'lib/osuny_api/models/communication_website_localization.rb', line 16 def id @id end |
#name ⇒ Object
Returns the value of attribute name.
18 19 20 |
# File 'lib/osuny_api/models/communication_website_localization.rb', line 18 def name @name end |
#published ⇒ Object
Returns the value of attribute published.
20 21 22 |
# File 'lib/osuny_api/models/communication_website_localization.rb', line 20 def published @published end |
#published_at ⇒ Object
Returns the value of attribute published_at.
22 23 24 |
# File 'lib/osuny_api/models/communication_website_localization.rb', line 22 def published_at @published_at end |
#social_email ⇒ Object
Returns the value of attribute social_email.
24 25 26 |
# File 'lib/osuny_api/models/communication_website_localization.rb', line 24 def @social_email end |
#social_facebook ⇒ Object
Returns the value of attribute social_facebook.
26 27 28 |
# File 'lib/osuny_api/models/communication_website_localization.rb', line 26 def @social_facebook end |
#social_github ⇒ Object
Returns the value of attribute social_github.
28 29 30 |
# File 'lib/osuny_api/models/communication_website_localization.rb', line 28 def @social_github end |
#social_instagram ⇒ Object
Returns the value of attribute social_instagram.
30 31 32 |
# File 'lib/osuny_api/models/communication_website_localization.rb', line 30 def @social_instagram end |
#social_linkedin ⇒ Object
Returns the value of attribute social_linkedin.
32 33 34 |
# File 'lib/osuny_api/models/communication_website_localization.rb', line 32 def @social_linkedin end |
#social_mastodon ⇒ Object
Returns the value of attribute social_mastodon.
34 35 36 |
# File 'lib/osuny_api/models/communication_website_localization.rb', line 34 def @social_mastodon end |
#social_peertube ⇒ Object
Returns the value of attribute social_peertube.
36 37 38 |
# File 'lib/osuny_api/models/communication_website_localization.rb', line 36 def @social_peertube end |
#social_tiktok ⇒ Object
Returns the value of attribute social_tiktok.
38 39 40 |
# File 'lib/osuny_api/models/communication_website_localization.rb', line 38 def @social_tiktok end |
#social_vimeo ⇒ Object
Returns the value of attribute social_vimeo.
40 41 42 |
# File 'lib/osuny_api/models/communication_website_localization.rb', line 40 def @social_vimeo end |
#social_x ⇒ Object
Returns the value of attribute social_x.
42 43 44 |
# File 'lib/osuny_api/models/communication_website_localization.rb', line 42 def @social_x end |
#social_youtube ⇒ Object
Returns the value of attribute social_youtube.
44 45 46 |
# File 'lib/osuny_api/models/communication_website_localization.rb', line 44 def @social_youtube end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
48 49 50 |
# File 'lib/osuny_api/models/communication_website_localization.rb', line 48 def updated_at @updated_at end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/osuny_api/models/communication_website_localization.rb', line 51 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'published' => :'published', :'published_at' => :'published_at', :'social_email' => :'social_email', :'social_facebook' => :'social_facebook', :'social_github' => :'social_github', :'social_instagram' => :'social_instagram', :'social_linkedin' => :'social_linkedin', :'social_mastodon' => :'social_mastodon', :'social_peertube' => :'social_peertube', :'social_tiktok' => :'social_tiktok', :'social_vimeo' => :'social_vimeo', :'social_x' => :'social_x', :'social_youtube' => :'social_youtube', :'created_at' => :'created_at', :'updated_at' => :'updated_at' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
250 251 252 |
# File 'lib/osuny_api/models/communication_website_localization.rb', line 250 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/osuny_api/models/communication_website_localization.rb', line 97 def self.openapi_nullable Set.new([ :'published_at', :'social_email', :'social_facebook', :'social_github', :'social_instagram', :'social_linkedin', :'social_mastodon', :'social_peertube', :'social_tiktok', :'social_vimeo', :'social_x', :'social_youtube', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/osuny_api/models/communication_website_localization.rb', line 74 def self.openapi_types { :'id' => :'Object', :'name' => :'Object', :'published' => :'Object', :'published_at' => :'Object', :'social_email' => :'Object', :'social_facebook' => :'Object', :'social_github' => :'Object', :'social_instagram' => :'Object', :'social_linkedin' => :'Object', :'social_mastodon' => :'Object', :'social_peertube' => :'Object', :'social_tiktok' => :'Object', :'social_vimeo' => :'Object', :'social_x' => :'Object', :'social_youtube' => :'Object', :'created_at' => :'Object', :'updated_at' => :'Object' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'lib/osuny_api/models/communication_website_localization.rb', line 213 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && published == o.published && published_at == o.published_at && == o. && == o. && == o. && == o. && == o. && == o. && == o. && == o. && == o. && == o. && == o. && created_at == o.created_at && updated_at == o.updated_at end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 |
# File 'lib/osuny_api/models/communication_website_localization.rb', line 280 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model OsunyApi.const_get(type).build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
349 350 351 352 353 354 355 356 357 358 359 360 361 |
# File 'lib/osuny_api/models/communication_website_localization.rb', line 349 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 |
# File 'lib/osuny_api/models/communication_website_localization.rb', line 257 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) elsif attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) end end self end |
#eql?(o) ⇒ Boolean
237 238 239 |
# File 'lib/osuny_api/models/communication_website_localization.rb', line 237 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
243 244 245 |
# File 'lib/osuny_api/models/communication_website_localization.rb', line 243 def hash [id, name, published, published_at, , , , , , , , , , , , created_at, updated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
200 201 202 203 |
# File 'lib/osuny_api/models/communication_website_localization.rb', line 200 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
325 326 327 |
# File 'lib/osuny_api/models/communication_website_localization.rb', line 325 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
331 332 333 334 335 336 337 338 339 340 341 342 343 |
# File 'lib/osuny_api/models/communication_website_localization.rb', line 331 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
319 320 321 |
# File 'lib/osuny_api/models/communication_website_localization.rb', line 319 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
207 208 209 |
# File 'lib/osuny_api/models/communication_website_localization.rb', line 207 def valid? true end |