Class: OsunyApi::CommunicationWebsitePortfolioProjectLocalization

Inherits:
Object
  • Object
show all
Defined in:
lib/osuny_api/models/communication_website_portfolio_project_localization.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CommunicationWebsitePortfolioProjectLocalization

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
# File 'lib/osuny_api/models/communication_website_portfolio_project_localization.rb', line 112

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `OsunyApi::CommunicationWebsitePortfolioProjectLocalization` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `OsunyApi::CommunicationWebsitePortfolioProjectLocalization`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'migration_identifier')
    self.migration_identifier = attributes[:'migration_identifier']
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  end

  if attributes.key?(:'featured_image')
    self.featured_image = attributes[:'featured_image']
  end

  if attributes.key?(:'header_cta')
    self.header_cta = attributes[:'header_cta']
  end

  if attributes.key?(:'header_cta_label')
    self.header_cta_label = attributes[:'header_cta_label']
  end

  if attributes.key?(:'header_cta_url')
    self.header_cta_url = attributes[:'header_cta_url']
  end

  if attributes.key?(:'meta_description')
    self.meta_description = attributes[:'meta_description']
  end

  if attributes.key?(:'published')
    self.published = attributes[:'published']
  end

  if attributes.key?(:'published_at')
    self.published_at = attributes[:'published_at']
  end

  if attributes.key?(:'slug')
    self.slug = attributes[:'slug']
  end

  if attributes.key?(:'subtitle')
    self.subtitle = attributes[:'subtitle']
  end

  if attributes.key?(:'summary')
    self.summary = attributes[:'summary']
  end

  if attributes.key?(:'aliases')
    if (value = attributes[:'aliases']).is_a?(Array)
      self.aliases = value
    end
  end

  if attributes.key?(:'blocks')
    if (value = attributes[:'blocks']).is_a?(Array)
      self.blocks = value
    end
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end
end

Instance Attribute Details

#aliasesObject

Returns the value of attribute aliases.



42
43
44
# File 'lib/osuny_api/models/communication_website_portfolio_project_localization.rb', line 42

def aliases
  @aliases
end

#blocksObject

Returns the value of attribute blocks.



44
45
46
# File 'lib/osuny_api/models/communication_website_portfolio_project_localization.rb', line 44

def blocks
  @blocks
end

#created_atObject

Returns the value of attribute created_at.



46
47
48
# File 'lib/osuny_api/models/communication_website_portfolio_project_localization.rb', line 46

def created_at
  @created_at
end

Returns the value of attribute featured_image.



22
23
24
# File 'lib/osuny_api/models/communication_website_portfolio_project_localization.rb', line 22

def featured_image
  @featured_image
end

#header_ctaObject

Returns the value of attribute header_cta.



24
25
26
# File 'lib/osuny_api/models/communication_website_portfolio_project_localization.rb', line 24

def header_cta
  @header_cta
end

#header_cta_labelObject

Returns the value of attribute header_cta_label.



26
27
28
# File 'lib/osuny_api/models/communication_website_portfolio_project_localization.rb', line 26

def header_cta_label
  @header_cta_label
end

#header_cta_urlObject

Returns the value of attribute header_cta_url.



28
29
30
# File 'lib/osuny_api/models/communication_website_portfolio_project_localization.rb', line 28

def header_cta_url
  @header_cta_url
end

#idObject

Returns the value of attribute id.



16
17
18
# File 'lib/osuny_api/models/communication_website_portfolio_project_localization.rb', line 16

def id
  @id
end

#meta_descriptionObject

Returns the value of attribute meta_description.



30
31
32
# File 'lib/osuny_api/models/communication_website_portfolio_project_localization.rb', line 30

def meta_description
  @meta_description
end

#migration_identifierObject

Returns the value of attribute migration_identifier.



18
19
20
# File 'lib/osuny_api/models/communication_website_portfolio_project_localization.rb', line 18

def migration_identifier
  @migration_identifier
end

#publishedObject

Returns the value of attribute published.



32
33
34
# File 'lib/osuny_api/models/communication_website_portfolio_project_localization.rb', line 32

def published
  @published
end

#published_atObject

Returns the value of attribute published_at.



34
35
36
# File 'lib/osuny_api/models/communication_website_portfolio_project_localization.rb', line 34

def published_at
  @published_at
end

#slugObject

Returns the value of attribute slug.



36
37
38
# File 'lib/osuny_api/models/communication_website_portfolio_project_localization.rb', line 36

def slug
  @slug
end

#subtitleObject

Returns the value of attribute subtitle.



38
39
40
# File 'lib/osuny_api/models/communication_website_portfolio_project_localization.rb', line 38

def subtitle
  @subtitle
end

#summaryObject

Returns the value of attribute summary.



40
41
42
# File 'lib/osuny_api/models/communication_website_portfolio_project_localization.rb', line 40

def summary
  @summary
end

#titleObject

Returns the value of attribute title.



20
21
22
# File 'lib/osuny_api/models/communication_website_portfolio_project_localization.rb', line 20

def title
  @title
end

#updated_atObject

Returns the value of attribute updated_at.



48
49
50
# File 'lib/osuny_api/models/communication_website_portfolio_project_localization.rb', line 48

def updated_at
  @updated_at
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/osuny_api/models/communication_website_portfolio_project_localization.rb', line 51

def self.attribute_map
  {
    :'id' => :'id',
    :'migration_identifier' => :'migration_identifier',
    :'title' => :'title',
    :'featured_image' => :'featured_image',
    :'header_cta' => :'header_cta',
    :'header_cta_label' => :'header_cta_label',
    :'header_cta_url' => :'header_cta_url',
    :'meta_description' => :'meta_description',
    :'published' => :'published',
    :'published_at' => :'published_at',
    :'slug' => :'slug',
    :'subtitle' => :'subtitle',
    :'summary' => :'summary',
    :'aliases' => :'aliases',
    :'blocks' => :'blocks',
    :'created_at' => :'created_at',
    :'updated_at' => :'updated_at'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



250
251
252
# File 'lib/osuny_api/models/communication_website_portfolio_project_localization.rb', line 250

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/osuny_api/models/communication_website_portfolio_project_localization.rb', line 97

def self.openapi_nullable
  Set.new([
    :'migration_identifier',
    :'header_cta',
    :'header_cta_label',
    :'header_cta_url',
    :'meta_description',
    :'published_at',
    :'subtitle',
    :'summary',
  ])
end

.openapi_typesObject

Attribute type mapping.



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/osuny_api/models/communication_website_portfolio_project_localization.rb', line 74

def self.openapi_types
  {
    :'id' => :'Object',
    :'migration_identifier' => :'Object',
    :'title' => :'Object',
    :'featured_image' => :'Object',
    :'header_cta' => :'Object',
    :'header_cta_label' => :'Object',
    :'header_cta_url' => :'Object',
    :'meta_description' => :'Object',
    :'published' => :'Object',
    :'published_at' => :'Object',
    :'slug' => :'Object',
    :'subtitle' => :'Object',
    :'summary' => :'Object',
    :'aliases' => :'Object',
    :'blocks' => :'Object',
    :'created_at' => :'Object',
    :'updated_at' => :'Object'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
# File 'lib/osuny_api/models/communication_website_portfolio_project_localization.rb', line 213

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      migration_identifier == o.migration_identifier &&
      title == o.title &&
      featured_image == o.featured_image &&
      header_cta == o.header_cta &&
      header_cta_label == o.header_cta_label &&
      header_cta_url == o.header_cta_url &&
      meta_description == o.meta_description &&
      published == o.published &&
      published_at == o.published_at &&
      slug == o.slug &&
      subtitle == o.subtitle &&
      summary == o.summary &&
      aliases == o.aliases &&
      blocks == o.blocks &&
      created_at == o.created_at &&
      updated_at == o.updated_at
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
# File 'lib/osuny_api/models/communication_website_portfolio_project_localization.rb', line 280

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    OsunyApi.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



349
350
351
352
353
354
355
356
357
358
359
360
361
# File 'lib/osuny_api/models/communication_website_portfolio_project_localization.rb', line 349

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
# File 'lib/osuny_api/models/communication_website_portfolio_project_localization.rb', line 257

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    elsif attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


237
238
239
# File 'lib/osuny_api/models/communication_website_portfolio_project_localization.rb', line 237

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



243
244
245
# File 'lib/osuny_api/models/communication_website_portfolio_project_localization.rb', line 243

def hash
  [id, migration_identifier, title, featured_image, header_cta, header_cta_label, header_cta_url, meta_description, published, published_at, slug, subtitle, summary, aliases, blocks, created_at, updated_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



200
201
202
203
# File 'lib/osuny_api/models/communication_website_portfolio_project_localization.rb', line 200

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



325
326
327
# File 'lib/osuny_api/models/communication_website_portfolio_project_localization.rb', line 325

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



331
332
333
334
335
336
337
338
339
340
341
342
343
# File 'lib/osuny_api/models/communication_website_portfolio_project_localization.rb', line 331

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



319
320
321
# File 'lib/osuny_api/models/communication_website_portfolio_project_localization.rb', line 319

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



207
208
209
# File 'lib/osuny_api/models/communication_website_portfolio_project_localization.rb', line 207

def valid?
  true
end