Class: OsunyApi::UniversityOrganization

Inherits:
Object
  • Object
show all
Defined in:
lib/osuny_api/models/university_organization.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UniversityOrganization

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/osuny_api/models/university_organization.rb', line 138

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `OsunyApi::UniversityOrganization` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `OsunyApi::UniversityOrganization`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'migration_identifier')
    self.migration_identifier = attributes[:'migration_identifier']
  end

  if attributes.key?(:'kind')
    self.kind = attributes[:'kind']
  end

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  end

  if attributes.key?(:'phone')
    self.phone = attributes[:'phone']
  end

  if attributes.key?(:'address')
    self.address = attributes[:'address']
  end

  if attributes.key?(:'zipcode')
    self.zipcode = attributes[:'zipcode']
  end

  if attributes.key?(:'city')
    self.city = attributes[:'city']
  end

  if attributes.key?(:'country')
    self.country = attributes[:'country']
  end

  if attributes.key?(:'latitude')
    self.latitude = attributes[:'latitude']
  end

  if attributes.key?(:'longitude')
    self.longitude = attributes[:'longitude']
  end

  if attributes.key?(:'nic')
    self.nic = attributes[:'nic']
  end

  if attributes.key?(:'siren')
    self.siren = attributes[:'siren']
  end

  if attributes.key?(:'localizations')
    if (value = attributes[:'localizations']).is_a?(Hash)
      self.localizations = value
    end
  end

  if attributes.key?(:'category_ids')
    if (value = attributes[:'category_ids']).is_a?(Array)
      self.category_ids = value
    end
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end
end

Instance Attribute Details

#addressObject

Returns the value of attribute address.



26
27
28
# File 'lib/osuny_api/models/university_organization.rb', line 26

def address
  @address
end

#category_idsObject

Returns the value of attribute category_ids.



45
46
47
# File 'lib/osuny_api/models/university_organization.rb', line 45

def category_ids
  @category_ids
end

#cityObject

Returns the value of attribute city.



30
31
32
# File 'lib/osuny_api/models/university_organization.rb', line 30

def city
  @city
end

#countryObject

Returns the value of attribute country.



32
33
34
# File 'lib/osuny_api/models/university_organization.rb', line 32

def country
  @country
end

#created_atObject

Returns the value of attribute created_at.



47
48
49
# File 'lib/osuny_api/models/university_organization.rb', line 47

def created_at
  @created_at
end

#emailObject

Returns the value of attribute email.



22
23
24
# File 'lib/osuny_api/models/university_organization.rb', line 22

def email
  @email
end

#idObject

Returns the value of attribute id.



16
17
18
# File 'lib/osuny_api/models/university_organization.rb', line 16

def id
  @id
end

#kindObject

Returns the value of attribute kind.



20
21
22
# File 'lib/osuny_api/models/university_organization.rb', line 20

def kind
  @kind
end

#latitudeObject

Returns the value of attribute latitude.



34
35
36
# File 'lib/osuny_api/models/university_organization.rb', line 34

def latitude
  @latitude
end

#localizationsObject

Localizations of the organization. The key is the language’s ISO 639-1 code.



43
44
45
# File 'lib/osuny_api/models/university_organization.rb', line 43

def localizations
  @localizations
end

#longitudeObject

Returns the value of attribute longitude.



36
37
38
# File 'lib/osuny_api/models/university_organization.rb', line 36

def longitude
  @longitude
end

#migration_identifierObject

Returns the value of attribute migration_identifier.



18
19
20
# File 'lib/osuny_api/models/university_organization.rb', line 18

def migration_identifier
  @migration_identifier
end

#nicObject

Returns the value of attribute nic.



38
39
40
# File 'lib/osuny_api/models/university_organization.rb', line 38

def nic
  @nic
end

#phoneObject

Returns the value of attribute phone.



24
25
26
# File 'lib/osuny_api/models/university_organization.rb', line 24

def phone
  @phone
end

#sirenObject

Returns the value of attribute siren.



40
41
42
# File 'lib/osuny_api/models/university_organization.rb', line 40

def siren
  @siren
end

#updated_atObject

Returns the value of attribute updated_at.



49
50
51
# File 'lib/osuny_api/models/university_organization.rb', line 49

def updated_at
  @updated_at
end

#zipcodeObject

Returns the value of attribute zipcode.



28
29
30
# File 'lib/osuny_api/models/university_organization.rb', line 28

def zipcode
  @zipcode
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/osuny_api/models/university_organization.rb', line 74

def self.attribute_map
  {
    :'id' => :'id',
    :'migration_identifier' => :'migration_identifier',
    :'kind' => :'kind',
    :'email' => :'email',
    :'phone' => :'phone',
    :'address' => :'address',
    :'zipcode' => :'zipcode',
    :'city' => :'city',
    :'country' => :'country',
    :'latitude' => :'latitude',
    :'longitude' => :'longitude',
    :'nic' => :'nic',
    :'siren' => :'siren',
    :'localizations' => :'localizations',
    :'category_ids' => :'category_ids',
    :'created_at' => :'created_at',
    :'updated_at' => :'updated_at'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



288
289
290
# File 'lib/osuny_api/models/university_organization.rb', line 288

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/osuny_api/models/university_organization.rb', line 120

def self.openapi_nullable
  Set.new([
    :'migration_identifier',
    :'email',
    :'phone',
    :'address',
    :'zipcode',
    :'city',
    :'country',
    :'latitude',
    :'longitude',
    :'nic',
    :'siren',
  ])
end

.openapi_typesObject

Attribute type mapping.



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/osuny_api/models/university_organization.rb', line 97

def self.openapi_types
  {
    :'id' => :'Object',
    :'migration_identifier' => :'Object',
    :'kind' => :'Object',
    :'email' => :'Object',
    :'phone' => :'Object',
    :'address' => :'Object',
    :'zipcode' => :'Object',
    :'city' => :'Object',
    :'country' => :'Object',
    :'latitude' => :'Object',
    :'longitude' => :'Object',
    :'nic' => :'Object',
    :'siren' => :'Object',
    :'localizations' => :'Object',
    :'category_ids' => :'Object',
    :'created_at' => :'Object',
    :'updated_at' => :'Object'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
# File 'lib/osuny_api/models/university_organization.rb', line 251

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      migration_identifier == o.migration_identifier &&
      kind == o.kind &&
      email == o.email &&
      phone == o.phone &&
      address == o.address &&
      zipcode == o.zipcode &&
      city == o.city &&
      country == o.country &&
      latitude == o.latitude &&
      longitude == o.longitude &&
      nic == o.nic &&
      siren == o.siren &&
      localizations == o.localizations &&
      category_ids == o.category_ids &&
      created_at == o.created_at &&
      updated_at == o.updated_at
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
# File 'lib/osuny_api/models/university_organization.rb', line 318

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    OsunyApi.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



387
388
389
390
391
392
393
394
395
396
397
398
399
# File 'lib/osuny_api/models/university_organization.rb', line 387

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
# File 'lib/osuny_api/models/university_organization.rb', line 295

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    elsif attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


275
276
277
# File 'lib/osuny_api/models/university_organization.rb', line 275

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



281
282
283
# File 'lib/osuny_api/models/university_organization.rb', line 281

def hash
  [id, migration_identifier, kind, email, phone, address, zipcode, city, country, latitude, longitude, nic, siren, localizations, category_ids, created_at, updated_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



226
227
228
229
# File 'lib/osuny_api/models/university_organization.rb', line 226

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



363
364
365
# File 'lib/osuny_api/models/university_organization.rb', line 363

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



369
370
371
372
373
374
375
376
377
378
379
380
381
# File 'lib/osuny_api/models/university_organization.rb', line 369

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



357
358
359
# File 'lib/osuny_api/models/university_organization.rb', line 357

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



233
234
235
236
237
# File 'lib/osuny_api/models/university_organization.rb', line 233

def valid?
  kind_validator = EnumAttributeValidator.new('Object', ['company', 'non_profit', 'government', 'public_organization', 'collective'])
  return false unless kind_validator.valid?(@kind)
  true
end