Class: OsunyApi::UniversityOrganizationCategoryLocalization

Inherits:
Object
  • Object
show all
Defined in:
lib/osuny_api/models/university_organization_category_localization.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UniversityOrganizationCategoryLocalization

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
# File 'lib/osuny_api/models/university_organization_category_localization.rb', line 109

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `OsunyApi::UniversityOrganizationCategoryLocalization` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `OsunyApi::UniversityOrganizationCategoryLocalization`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'migration_identifier')
    self.migration_identifier = attributes[:'migration_identifier']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'breadcrumb_title')
    self.breadcrumb_title = attributes[:'breadcrumb_title']
  end

  if attributes.key?(:'featured_image')
    self.featured_image = attributes[:'featured_image']
  end

  if attributes.key?(:'header_cta')
    self.header_cta = attributes[:'header_cta']
  end

  if attributes.key?(:'header_cta_label')
    self.header_cta_label = attributes[:'header_cta_label']
  end

  if attributes.key?(:'header_cta_url')
    self.header_cta_url = attributes[:'header_cta_url']
  end

  if attributes.key?(:'header_text')
    self.header_text = attributes[:'header_text']
  end

  if attributes.key?(:'meta_description')
    self.meta_description = attributes[:'meta_description']
  end

  if attributes.key?(:'slug')
    self.slug = attributes[:'slug']
  end

  if attributes.key?(:'subtitle')
    self.subtitle = attributes[:'subtitle']
  end

  if attributes.key?(:'summary')
    self.summary = attributes[:'summary']
  end

  if attributes.key?(:'blocks')
    if (value = attributes[:'blocks']).is_a?(Array)
      self.blocks = value
    end
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end
end

Instance Attribute Details

#blocksObject

Returns the value of attribute blocks.



42
43
44
# File 'lib/osuny_api/models/university_organization_category_localization.rb', line 42

def blocks
  @blocks
end

Returns the value of attribute breadcrumb_title.



22
23
24
# File 'lib/osuny_api/models/university_organization_category_localization.rb', line 22

def breadcrumb_title
  @breadcrumb_title
end

#created_atObject

Returns the value of attribute created_at.



44
45
46
# File 'lib/osuny_api/models/university_organization_category_localization.rb', line 44

def created_at
  @created_at
end

Returns the value of attribute featured_image.



24
25
26
# File 'lib/osuny_api/models/university_organization_category_localization.rb', line 24

def featured_image
  @featured_image
end

#header_ctaObject

Returns the value of attribute header_cta.



26
27
28
# File 'lib/osuny_api/models/university_organization_category_localization.rb', line 26

def header_cta
  @header_cta
end

#header_cta_labelObject

Returns the value of attribute header_cta_label.



28
29
30
# File 'lib/osuny_api/models/university_organization_category_localization.rb', line 28

def header_cta_label
  @header_cta_label
end

#header_cta_urlObject

Returns the value of attribute header_cta_url.



30
31
32
# File 'lib/osuny_api/models/university_organization_category_localization.rb', line 30

def header_cta_url
  @header_cta_url
end

#header_textObject

Returns the value of attribute header_text.



32
33
34
# File 'lib/osuny_api/models/university_organization_category_localization.rb', line 32

def header_text
  @header_text
end

#idObject

Returns the value of attribute id.



16
17
18
# File 'lib/osuny_api/models/university_organization_category_localization.rb', line 16

def id
  @id
end

#meta_descriptionObject

Returns the value of attribute meta_description.



34
35
36
# File 'lib/osuny_api/models/university_organization_category_localization.rb', line 34

def meta_description
  @meta_description
end

#migration_identifierObject

Returns the value of attribute migration_identifier.



18
19
20
# File 'lib/osuny_api/models/university_organization_category_localization.rb', line 18

def migration_identifier
  @migration_identifier
end

#nameObject

Returns the value of attribute name.



20
21
22
# File 'lib/osuny_api/models/university_organization_category_localization.rb', line 20

def name
  @name
end

#slugObject

Returns the value of attribute slug.



36
37
38
# File 'lib/osuny_api/models/university_organization_category_localization.rb', line 36

def slug
  @slug
end

#subtitleObject

Returns the value of attribute subtitle.



38
39
40
# File 'lib/osuny_api/models/university_organization_category_localization.rb', line 38

def subtitle
  @subtitle
end

#summaryObject

Returns the value of attribute summary.



40
41
42
# File 'lib/osuny_api/models/university_organization_category_localization.rb', line 40

def summary
  @summary
end

#updated_atObject

Returns the value of attribute updated_at.



46
47
48
# File 'lib/osuny_api/models/university_organization_category_localization.rb', line 46

def updated_at
  @updated_at
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
# File 'lib/osuny_api/models/university_organization_category_localization.rb', line 49

def self.attribute_map
  {
    :'id' => :'id',
    :'migration_identifier' => :'migration_identifier',
    :'name' => :'name',
    :'breadcrumb_title' => :'breadcrumb_title',
    :'featured_image' => :'featured_image',
    :'header_cta' => :'header_cta',
    :'header_cta_label' => :'header_cta_label',
    :'header_cta_url' => :'header_cta_url',
    :'header_text' => :'header_text',
    :'meta_description' => :'meta_description',
    :'slug' => :'slug',
    :'subtitle' => :'subtitle',
    :'summary' => :'summary',
    :'blocks' => :'blocks',
    :'created_at' => :'created_at',
    :'updated_at' => :'updated_at'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



240
241
242
# File 'lib/osuny_api/models/university_organization_category_localization.rb', line 240

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/osuny_api/models/university_organization_category_localization.rb', line 93

def self.openapi_nullable
  Set.new([
    :'migration_identifier',
    :'breadcrumb_title',
    :'header_cta',
    :'header_cta_label',
    :'header_cta_url',
    :'header_text',
    :'meta_description',
    :'subtitle',
    :'summary',
  ])
end

.openapi_typesObject

Attribute type mapping.



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/osuny_api/models/university_organization_category_localization.rb', line 71

def self.openapi_types
  {
    :'id' => :'Object',
    :'migration_identifier' => :'Object',
    :'name' => :'Object',
    :'breadcrumb_title' => :'Object',
    :'featured_image' => :'Object',
    :'header_cta' => :'Object',
    :'header_cta_label' => :'Object',
    :'header_cta_url' => :'Object',
    :'header_text' => :'Object',
    :'meta_description' => :'Object',
    :'slug' => :'Object',
    :'subtitle' => :'Object',
    :'summary' => :'Object',
    :'blocks' => :'Object',
    :'created_at' => :'Object',
    :'updated_at' => :'Object'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/osuny_api/models/university_organization_category_localization.rb', line 204

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      migration_identifier == o.migration_identifier &&
      name == o.name &&
      breadcrumb_title == o.breadcrumb_title &&
      featured_image == o.featured_image &&
      header_cta == o.header_cta &&
      header_cta_label == o.header_cta_label &&
      header_cta_url == o.header_cta_url &&
      header_text == o.header_text &&
      meta_description == o.meta_description &&
      slug == o.slug &&
      subtitle == o.subtitle &&
      summary == o.summary &&
      blocks == o.blocks &&
      created_at == o.created_at &&
      updated_at == o.updated_at
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
# File 'lib/osuny_api/models/university_organization_category_localization.rb', line 270

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    OsunyApi.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



339
340
341
342
343
344
345
346
347
348
349
350
351
# File 'lib/osuny_api/models/university_organization_category_localization.rb', line 339

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
# File 'lib/osuny_api/models/university_organization_category_localization.rb', line 247

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    elsif attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


227
228
229
# File 'lib/osuny_api/models/university_organization_category_localization.rb', line 227

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



233
234
235
# File 'lib/osuny_api/models/university_organization_category_localization.rb', line 233

def hash
  [id, migration_identifier, name, breadcrumb_title, featured_image, header_cta, header_cta_label, header_cta_url, header_text, meta_description, slug, subtitle, summary, blocks, created_at, updated_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



191
192
193
194
# File 'lib/osuny_api/models/university_organization_category_localization.rb', line 191

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



315
316
317
# File 'lib/osuny_api/models/university_organization_category_localization.rb', line 315

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



321
322
323
324
325
326
327
328
329
330
331
332
333
# File 'lib/osuny_api/models/university_organization_category_localization.rb', line 321

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



309
310
311
# File 'lib/osuny_api/models/university_organization_category_localization.rb', line 309

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



198
199
200
# File 'lib/osuny_api/models/university_organization_category_localization.rb', line 198

def valid?
  true
end