Class: OsunyApi::UniversityOrganizationLocalization

Inherits:
Object
  • Object
show all
Defined in:
lib/osuny_api/models/university_organization_localization.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UniversityOrganizationLocalization

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/osuny_api/models/university_organization_localization.rb', line 129

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `OsunyApi::UniversityOrganizationLocalization` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `OsunyApi::UniversityOrganizationLocalization`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'migration_identifier')
    self.migration_identifier = attributes[:'migration_identifier']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'long_name')
    self.long_name = attributes[:'long_name']
  end

  if attributes.key?(:'featured_image')
    self.featured_image = attributes[:'featured_image']
  end

  if attributes.key?(:'meta_description')
    self.meta_description = attributes[:'meta_description']
  end

  if attributes.key?(:'published')
    self.published = attributes[:'published']
  end

  if attributes.key?(:'published_at')
    self.published_at = attributes[:'published_at']
  end

  if attributes.key?(:'address_name')
    self.address_name = attributes[:'address_name']
  end

  if attributes.key?(:'address_additional')
    self.address_additional = attributes[:'address_additional']
  end

  if attributes.key?(:'linkedin')
    self.linkedin = attributes[:'linkedin']
  end

  if attributes.key?(:'mastodon')
    self.mastodon = attributes[:'mastodon']
  end

  if attributes.key?(:'twitter')
    self.twitter = attributes[:'twitter']
  end

  if attributes.key?(:'url')
    self.url = attributes[:'url']
  end

  if attributes.key?(:'slug')
    self.slug = attributes[:'slug']
  end

  if attributes.key?(:'summary')
    self.summary = attributes[:'summary']
  end

  if attributes.key?(:'text')
    self.text = attributes[:'text']
  end

  if attributes.key?(:'blocks')
    if (value = attributes[:'blocks']).is_a?(Array)
      self.blocks = value
    end
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end
end

Instance Attribute Details

#address_additionalObject

Returns the value of attribute address_additional.



34
35
36
# File 'lib/osuny_api/models/university_organization_localization.rb', line 34

def address_additional
  @address_additional
end

#address_nameObject

Returns the value of attribute address_name.



32
33
34
# File 'lib/osuny_api/models/university_organization_localization.rb', line 32

def address_name
  @address_name
end

#blocksObject

Returns the value of attribute blocks.



50
51
52
# File 'lib/osuny_api/models/university_organization_localization.rb', line 50

def blocks
  @blocks
end

#created_atObject

Returns the value of attribute created_at.



52
53
54
# File 'lib/osuny_api/models/university_organization_localization.rb', line 52

def created_at
  @created_at
end

Returns the value of attribute featured_image.



24
25
26
# File 'lib/osuny_api/models/university_organization_localization.rb', line 24

def featured_image
  @featured_image
end

#idObject

Returns the value of attribute id.



16
17
18
# File 'lib/osuny_api/models/university_organization_localization.rb', line 16

def id
  @id
end

#linkedinObject

Returns the value of attribute linkedin.



36
37
38
# File 'lib/osuny_api/models/university_organization_localization.rb', line 36

def linkedin
  @linkedin
end

#long_nameObject

Returns the value of attribute long_name.



22
23
24
# File 'lib/osuny_api/models/university_organization_localization.rb', line 22

def long_name
  @long_name
end

#mastodonObject

Returns the value of attribute mastodon.



38
39
40
# File 'lib/osuny_api/models/university_organization_localization.rb', line 38

def mastodon
  @mastodon
end

#meta_descriptionObject

Returns the value of attribute meta_description.



26
27
28
# File 'lib/osuny_api/models/university_organization_localization.rb', line 26

def meta_description
  @meta_description
end

#migration_identifierObject

Returns the value of attribute migration_identifier.



18
19
20
# File 'lib/osuny_api/models/university_organization_localization.rb', line 18

def migration_identifier
  @migration_identifier
end

#nameObject

Returns the value of attribute name.



20
21
22
# File 'lib/osuny_api/models/university_organization_localization.rb', line 20

def name
  @name
end

#publishedObject

Returns the value of attribute published.



28
29
30
# File 'lib/osuny_api/models/university_organization_localization.rb', line 28

def published
  @published
end

#published_atObject

Returns the value of attribute published_at.



30
31
32
# File 'lib/osuny_api/models/university_organization_localization.rb', line 30

def published_at
  @published_at
end

#slugObject

Returns the value of attribute slug.



44
45
46
# File 'lib/osuny_api/models/university_organization_localization.rb', line 44

def slug
  @slug
end

#summaryObject

Returns the value of attribute summary.



46
47
48
# File 'lib/osuny_api/models/university_organization_localization.rb', line 46

def summary
  @summary
end

#textObject

Returns the value of attribute text.



48
49
50
# File 'lib/osuny_api/models/university_organization_localization.rb', line 48

def text
  @text
end

#twitterObject

Returns the value of attribute twitter.



40
41
42
# File 'lib/osuny_api/models/university_organization_localization.rb', line 40

def twitter
  @twitter
end

#updated_atObject

Returns the value of attribute updated_at.



54
55
56
# File 'lib/osuny_api/models/university_organization_localization.rb', line 54

def updated_at
  @updated_at
end

#urlObject

Returns the value of attribute url.



42
43
44
# File 'lib/osuny_api/models/university_organization_localization.rb', line 42

def url
  @url
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/osuny_api/models/university_organization_localization.rb', line 57

def self.attribute_map
  {
    :'id' => :'id',
    :'migration_identifier' => :'migration_identifier',
    :'name' => :'name',
    :'long_name' => :'long_name',
    :'featured_image' => :'featured_image',
    :'meta_description' => :'meta_description',
    :'published' => :'published',
    :'published_at' => :'published_at',
    :'address_name' => :'address_name',
    :'address_additional' => :'address_additional',
    :'linkedin' => :'linkedin',
    :'mastodon' => :'mastodon',
    :'twitter' => :'twitter',
    :'url' => :'url',
    :'slug' => :'slug',
    :'summary' => :'summary',
    :'text' => :'text',
    :'blocks' => :'blocks',
    :'created_at' => :'created_at',
    :'updated_at' => :'updated_at'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



280
281
282
# File 'lib/osuny_api/models/university_organization_localization.rb', line 280

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/osuny_api/models/university_organization_localization.rb', line 109

def self.openapi_nullable
  Set.new([
    :'migration_identifier',
    :'long_name',
    :'meta_description',
    :'published_at',
    :'address_name',
    :'address_additional',
    :'linkedin',
    :'mastodon',
    :'twitter',
    :'url',
    :'slug',
    :'summary',
    :'text',
  ])
end

.openapi_typesObject

Attribute type mapping.



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/osuny_api/models/university_organization_localization.rb', line 83

def self.openapi_types
  {
    :'id' => :'Object',
    :'migration_identifier' => :'Object',
    :'name' => :'Object',
    :'long_name' => :'Object',
    :'featured_image' => :'Object',
    :'meta_description' => :'Object',
    :'published' => :'Object',
    :'published_at' => :'Object',
    :'address_name' => :'Object',
    :'address_additional' => :'Object',
    :'linkedin' => :'Object',
    :'mastodon' => :'Object',
    :'twitter' => :'Object',
    :'url' => :'Object',
    :'slug' => :'Object',
    :'summary' => :'Object',
    :'text' => :'Object',
    :'blocks' => :'Object',
    :'created_at' => :'Object',
    :'updated_at' => :'Object'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
# File 'lib/osuny_api/models/university_organization_localization.rb', line 240

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      migration_identifier == o.migration_identifier &&
      name == o.name &&
      long_name == o.long_name &&
      featured_image == o.featured_image &&
      meta_description == o.meta_description &&
      published == o.published &&
      published_at == o.published_at &&
      address_name == o.address_name &&
      address_additional == o.address_additional &&
      linkedin == o.linkedin &&
      mastodon == o.mastodon &&
      twitter == o.twitter &&
      url == o.url &&
      slug == o.slug &&
      summary == o.summary &&
      text == o.text &&
      blocks == o.blocks &&
      created_at == o.created_at &&
      updated_at == o.updated_at
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/osuny_api/models/university_organization_localization.rb', line 310

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    OsunyApi.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



379
380
381
382
383
384
385
386
387
388
389
390
391
# File 'lib/osuny_api/models/university_organization_localization.rb', line 379

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
# File 'lib/osuny_api/models/university_organization_localization.rb', line 287

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    elsif attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


267
268
269
# File 'lib/osuny_api/models/university_organization_localization.rb', line 267

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



273
274
275
# File 'lib/osuny_api/models/university_organization_localization.rb', line 273

def hash
  [id, migration_identifier, name, long_name, featured_image, meta_description, published, published_at, address_name, address_additional, linkedin, mastodon, twitter, url, slug, summary, text, blocks, created_at, updated_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



227
228
229
230
# File 'lib/osuny_api/models/university_organization_localization.rb', line 227

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



355
356
357
# File 'lib/osuny_api/models/university_organization_localization.rb', line 355

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



361
362
363
364
365
366
367
368
369
370
371
372
373
# File 'lib/osuny_api/models/university_organization_localization.rb', line 361

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



349
350
351
# File 'lib/osuny_api/models/university_organization_localization.rb', line 349

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



234
235
236
# File 'lib/osuny_api/models/university_organization_localization.rb', line 234

def valid?
  true
end